@@ -7,30 +7,32 @@ Created on Wed May 25 12:39:41 2022
 quality check for trigger
 """
 import argparse
+import logging
 import os
 import sys
 
 import pandas as pd
 
+log = logging.getLogger(__name__)
 
 def check_trigger(baseline, outdir):
     bfile = os.path.join(baseline, 'trigg_info.csv')
     if not os.path.exists(bfile):
-        print(f'Cannot find baseline trigger file(s) {bfile}')
+        log.error(f'Cannot find baseline trigger file(s) {bfile}')
         return False
 
     tarfile = os.path.join(outdir, 'trigger', 'trigg_info.csv')
     if not os.path.exists(tarfile):
-        print(f'Cannot find reference trigger file(s) {tarfile}')
+        log.error(f'Cannot find reference trigger file(s) {tarfile}')
         return False
 
-    print('Comparing TRIGGERED stations...\n')
+    log.info('Comparing TRIGGERED stations...\n')
     bdat = pd.read_csv(bfile, header=0)
     tdat = pd.read_csv(tarfile, header=0)
     if len(bdat.compare(tdat)) > 0:
-        print('Differences found in trigger info')
+        log.error('Differences found in trigger info')
         return False
-    print('All good')
+    log.info('All good')
     return True
 
 
